summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/pc080sn.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/pc080sn.cpp')
-rw-r--r--src/mame/video/pc080sn.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/video/pc080sn.cpp b/src/mame/video/pc080sn.cpp
index f277554f771..800be22ed24 100644
--- a/src/mame/video/pc080sn.cpp
+++ b/src/mame/video/pc080sn.cpp
@@ -74,13 +74,13 @@ pc080sn_device::pc080sn_device(const machine_config &mconfig, const char *tag, d
}
//-------------------------------------------------
// static_set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------
-void pc080sn_device::static_set_gfxdecode_tag(device_t &device, const char *tag)
+void pc080sn_device::set_gfxdecode_tag(const char *tag)
{
- downcast<pc080sn_device &>(device).m_gfxdecode.set_tag(tag);
+ m_gfxdecode.set_tag(tag);
}
//-------------------------------------------------
@@ -74,13 +74,13 @@ pc080sn_device::pc080sn_device(const machine_config &mconfig, const char *tag, d
}
//-------------------------------------------------
-// static_set_gfxdecode_tag: Set the tag of the
+// set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------